@@ -12,6 +12,6 @@ class T1CheckIds(ValidationRule):
         if self.include_value_ids is None or self.exclude_value_ids is None:
             return
 
-        intrsect = set(self.include_value_ids).intersection(self.exclude_value_ids)
-        if len(intrsect) > 0:
+        intersect = set(self.include_value_ids).intersection(self.exclude_value_ids)
+        if len(intersect) > 0:
             raise ValidationException("Cannot have the same value id in both exclude and include lists.")
